? profiles/testing
Index: includes/install.core.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/install.core.inc,v
retrieving revision 1.25
diff -u -p -r1.25 install.core.inc
--- includes/install.core.inc	2 Jul 2010 15:32:10 -0000	1.25
+++ includes/install.core.inc	13 Jul 2010 15:59:26 -0000
@@ -1111,6 +1111,11 @@ function install_select_profile_form($fo
     include_once DRUPAL_ROOT . '/' . $profile->uri;
 
     $details = install_profile_info($profile->name);
+    // Don't show hidden profiles. This is used by to hide the testing profile,
+    // which only exists to speed up test runs.
+    if ($details['hidden'] === TRUE) {
+      continue;
+    }
     $profiles[$profile->name] = $details;
 
     // Determine the name of the profile; default to file name if defined name
Index: includes/install.inc
===================================================================
RCS file: /cvs/drupal/drupal/includes/install.inc,v
retrieving revision 1.136
diff -u -p -r1.136 install.inc
--- includes/install.inc	21 Jun 2010 02:27:47 -0000	1.136
+++ includes/install.inc	13 Jul 2010 15:59:28 -0000
@@ -1020,6 +1020,7 @@ function install_profile_info($profile, 
       'description' => '',
       'distribution_name' => 'Drupal',
       'version' => NULL,
+      'hidden' => FALSE,
       'php' => DRUPAL_MINIMUM_PHP,
     );
     $info = drupal_parse_info_file("profiles/$profile/$profile.info") + $defaults;
Index: modules/aggregator/aggregator.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/aggregator/aggregator.test,v
retrieving revision 1.39
diff -u -p -r1.39 aggregator.test
--- modules/aggregator/aggregator.test	24 Mar 2010 08:51:42 -0000	1.39
+++ modules/aggregator/aggregator.test	13 Jul 2010 15:59:29 -0000
@@ -261,6 +261,8 @@ EOF;
 }
 
 class AddFeedTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Add feed functionality',
@@ -292,6 +294,8 @@ class AddFeedTestCase extends Aggregator
 }
 
 class UpdateFeedTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Update feed functionality',
@@ -334,6 +338,8 @@ class UpdateFeedTestCase extends Aggrega
 }
 
 class RemoveFeedTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Remove feed functionality',
@@ -362,6 +368,8 @@ class RemoveFeedTestCase extends Aggrega
 }
 
 class UpdateFeedItemTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Update feed item functionality',
@@ -423,6 +431,8 @@ class UpdateFeedItemTestCase extends Agg
 }
 
 class RemoveFeedItemTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Remove feed item functionality',
@@ -461,6 +471,8 @@ class RemoveFeedItemTestCase extends Agg
 }
 
 class CategorizeFeedItemTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Categorize feed item functionality',
@@ -518,6 +530,8 @@ class CategorizeFeedItemTestCase extends
 }
 
 class ImportOPMLTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Import feeds from OPML functionality',
@@ -642,6 +656,8 @@ class ImportOPMLTestCase extends Aggrega
 }
 
 class AggregatorCronTestCase extends AggregatorTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Update on cron functionality',
Index: modules/block/block.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/block/block.test,v
retrieving revision 1.54
diff -u -p -r1.54 block.test
--- modules/block/block.test	8 Jul 2010 03:41:27 -0000	1.54
+++ modules/block/block.test	13 Jul 2010 15:59:30 -0000
@@ -7,6 +7,7 @@
  */
 
 class BlockTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $regions;
   protected $admin_user;
 
@@ -282,6 +283,8 @@ class BlockTestCase extends DrupalWebTes
 }
 
 class NonDefaultBlockAdmin extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Non default theme admin',
@@ -313,6 +316,10 @@ class NewDefaultThemeBlocks extends Drup
     );
   }
 
+  public function setUp() {
+    parent::setUp('block');
+  }
+
   /**
    * Check the enabled Garland blocks are correctly copied over.
    */
@@ -355,6 +362,8 @@ class NewDefaultThemeBlocks extends Drup
  * Test the block system with admin themes.
  */
 class BlockAdminThemeTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Admin theme block admin accessibility',
@@ -387,6 +396,7 @@ class BlockAdminThemeTestCase extends Dr
  * Test block caching.
  */
 class BlockCacheTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
   protected $normal_user;
   protected $normal_user_alt;
@@ -577,6 +587,7 @@ class BlockCacheTestCase extends DrupalW
  * Test block HTML id validity.
  */
 class BlockHTMLIdTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/blog/blog.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/blog/blog.test,v
retrieving revision 1.27
diff -u -p -r1.27 blog.test
--- modules/blog/blog.test	8 Jul 2010 03:41:27 -0000	1.27
+++ modules/blog/blog.test	13 Jul 2010 15:59:30 -0000
@@ -2,6 +2,7 @@
 // $Id: blog.test,v 1.27 2010/07/08 03:41:27 webchick Exp $
 
 class BlogTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $big_user;
   protected $own_user;
   protected $any_user;
Index: modules/book/book.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/book/book.test,v
retrieving revision 1.24
diff -u -p -r1.24 book.test
--- modules/book/book.test	22 Apr 2010 23:31:23 -0000	1.24
+++ modules/book/book.test	13 Jul 2010 15:59:31 -0000
@@ -2,6 +2,7 @@
 // $Id: book.test,v 1.24 2010/04/22 23:31:23 webchick Exp $
 
 class BookTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $book;
   // $book_author is a user with permission to author a book.
   protected $book_author;
@@ -248,6 +249,8 @@ class BookTestCase extends DrupalWebTest
 }
 
 class BookBlockTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block availability',
Index: modules/comment/comment.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/comment/comment.test,v
retrieving revision 1.84
diff -u -p -r1.84 comment.test
--- modules/comment/comment.test	7 Jul 2010 17:00:42 -0000	1.84
+++ modules/comment/comment.test	13 Jul 2010 15:59:33 -0000
@@ -250,6 +250,8 @@ class CommentHelperCase extends DrupalWe
 }
 
 class CommentInterfaceTest extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment interface',
@@ -396,6 +398,8 @@ class CommentInterfaceTest extends Comme
  * Test previewing comments.
  */
 class CommentPreviewTest extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment preview',
@@ -473,6 +477,8 @@ class CommentPreviewTest extends Comment
 }
 
 class CommentAnonymous extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Anonymous comments',
@@ -601,6 +607,7 @@ class CommentAnonymous extends CommentHe
  * Verify pagination of comments.
  */
 class CommentPagerTest extends CommentHelperCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -864,6 +871,8 @@ class CommentPagerTest extends CommentHe
 }
 
 class CommentApprovalTest extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment approval',
@@ -988,6 +997,8 @@ class CommentApprovalTest extends Commen
  * Functional tests for the comment module blocks.
  */
 class CommentBlockFunctionalTest extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment blocks',
@@ -1075,6 +1086,8 @@ class CommentBlockFunctionalTest extends
  * Unit tests for comment module integration with RSS feeds.
  */
 class CommentRSSUnitTest extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment RSS',
@@ -1107,6 +1120,8 @@ class CommentRSSUnitTest extends Comment
  * Test to make sure comment content is rebuilt.
  */
 class CommentContentRebuild extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment Rebuild',
@@ -1147,6 +1162,8 @@ class CommentContentRebuild extends Comm
  * Test comment token replacement in strings.
  */
 class CommentTokenReplaceTestCase extends CommentHelperCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Comment token replacement',
Index: modules/contact/contact.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/contact/contact.test,v
retrieving revision 1.43
diff -u -p -r1.43 contact.test
--- modules/contact/contact.test	22 Mar 2010 17:52:58 -0000	1.43
+++ modules/contact/contact.test	13 Jul 2010 15:59:33 -0000
@@ -280,6 +280,7 @@ class ContactSitewideTestCase extends Dr
  * Test the personal contact form.
  */
 class ContactPersonalTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   private $admin_user;
   private $web_user;
   private $contact_user;
Index: modules/dashboard/dashboard.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/dashboard/dashboard.test,v
retrieving revision 1.1
diff -u -p -r1.1 dashboard.test
--- modules/dashboard/dashboard.test	2 Jul 2010 15:24:31 -0000	1.1
+++ modules/dashboard/dashboard.test	13 Jul 2010 15:59:33 -0000
@@ -16,7 +16,7 @@ class DashboardAccessTestCase extends Dr
   }
 
   function setUp() {
-    parent::setUp();
+    parent::setUp('block', 'dashboard', 'comment');
 
     // Create and log in an administrative user having access to the dashboard.
     $admin_user = $this->drupalCreateUser(array('access administration pages', 'administer blocks'));
Index: modules/dblog/dblog.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/dblog/dblog.test,v
retrieving revision 1.36
diff -u -p -r1.36 dblog.test
--- modules/dblog/dblog.test	27 Mar 2010 14:24:14 -0000	1.36
+++ modules/dblog/dblog.test	13 Jul 2010 15:59:34 -0000
@@ -2,6 +2,7 @@
 // $Id: dblog.test,v 1.36 2010/03/27 14:24:14 dries Exp $
 
 class DBLogTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $big_user;
   protected $any_user;
 
Index: modules/field/modules/list/tests/list.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/field/modules/list/tests/list.test,v
retrieving revision 1.5
diff -u -p -r1.5 list.test
--- modules/field/modules/list/tests/list.test	27 Mar 2010 12:49:32 -0000	1.5
+++ modules/field/modules/list/tests/list.test	13 Jul 2010 15:59:34 -0000
@@ -101,6 +101,8 @@ class ListFieldTestCase extends FieldTes
 * List module UI tests.
 */
 class ListFieldUITestCase extends FieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'List field UI',
Index: modules/field/modules/text/text.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/field/modules/text/text.test,v
retrieving revision 1.24
diff -u -p -r1.24 text.test
--- modules/field/modules/text/text.test	28 Jun 2010 20:58:42 -0000	1.24
+++ modules/field/modules/text/text.test	13 Jul 2010 15:59:35 -0000
@@ -230,6 +230,8 @@ class TextFieldTestCase extends DrupalWe
 }
 
 class TextSummaryTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Text summary',
@@ -375,6 +377,8 @@ class TextSummaryTestCase extends Drupal
 }
 
 class TextTranslationTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Text translation',
Index: modules/field/tests/field.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/field/tests/field.test,v
retrieving revision 1.33
diff -u -p -r1.33 field.test
--- modules/field/tests/field.test	17 Jun 2010 13:16:57 -0000	1.33
+++ modules/field/tests/field.test	13 Jul 2010 15:59:39 -0000
@@ -970,6 +970,7 @@ class FieldAttachOtherTestCase extends F
 }
 
 class FieldInfoTestCase extends FieldTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/field_ui/field_ui.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/field_ui/field_ui.test,v
retrieving revision 1.18
diff -u -p -r1.18 field_ui.test
--- modules/field_ui/field_ui.test	27 Jun 2010 18:05:54 -0000	1.18
+++ modules/field_ui/field_ui.test	13 Jul 2010 15:59:40 -0000
@@ -10,7 +10,9 @@
  * Field UI tests.
  */
 class FieldUITestCase extends DrupalWebTestCase {
-    public static function getInfo() {
+  protected $profile = 'standard';
+
+  public static function getInfo() {
     return array(
       'name' => 'Field UI tests',
       'description' => 'Test the field UI functionality.',
Index: modules/file/tests/file.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/file/tests/file.test,v
retrieving revision 1.18
diff -u -p -r1.18 file.test
--- modules/file/tests/file.test	2 Jul 2010 12:37:57 -0000	1.18
+++ modules/file/tests/file.test	13 Jul 2010 15:59:41 -0000
@@ -16,6 +16,7 @@ class FileFieldTestCase extends DrupalWe
     parent::setUp('file');
     $this->admin_user = $this->drupalCreateUser(array('access content', 'access administration pages', 'administer site configuration', 'administer users', 'administer content types', 'administer nodes', 'bypass node access'));
     $this->drupalLogin($this->admin_user);
+    $this->drupalCreateDefaultContentTypes();
   }
 
   /**
@@ -284,6 +285,8 @@ class FileFieldWidgetTestCase extends Fi
  * Test class to test file handling with node revisions.
  */
 class FileFieldRevisionTestCase extends FileFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'File field revision test',
@@ -399,6 +402,8 @@ class FileFieldRevisionTestCase extends 
  * Test class to check that formatters are working properly.
  */
 class FileFieldDisplayTestCase extends FileFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'File field display tests',
@@ -450,6 +455,7 @@ class FileFieldDisplayTestCase extends F
  * Test class to check for various validations.
  */
 class FileFieldValidateTestCase extends FileFieldTestCase {
+  protected $profile = 'standard';
   protected $field;
   protected $node_type;
 
@@ -609,6 +615,8 @@ class FileFieldValidateTestCase extends 
  * Test class to check that files are uploaded to proper locations.
  */
 class FileFieldPathTestCase extends FileFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'File field file path tests',
@@ -687,6 +695,8 @@ class FileFieldPathTestCase extends File
  * Test file token replacement in strings.
  */
 class FileTokenReplaceTestCase extends FileFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'File token replacement',
Index: modules/filter/filter.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/filter/filter.test,v
retrieving revision 1.69
diff -u -p -r1.69 filter.test
--- modules/filter/filter.test	1 Jul 2010 19:41:18 -0000	1.69
+++ modules/filter/filter.test	13 Jul 2010 15:59:43 -0000
@@ -156,6 +156,8 @@ class FilterCRUDTestCase extends DrupalW
 }
 
 class FilterAdminTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Filter administration functionality',
@@ -396,6 +398,7 @@ class FilterAdminTestCase extends Drupal
 }
 
 class FilterFormatAccessTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
   protected $web_user;
   protected $allowed_format;
Index: modules/forum/forum.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/forum/forum.test,v
retrieving revision 1.57
diff -u -p -r1.57 forum.test
--- modules/forum/forum.test	8 Jul 2010 03:41:27 -0000	1.57
+++ modules/forum/forum.test	13 Jul 2010 15:59:44 -0000
@@ -2,6 +2,7 @@
 // $Id: forum.test,v 1.57 2010/07/08 03:41:27 webchick Exp $
 
 class ForumTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
   protected $edit_own_topics_user;
   protected $edit_any_topics_user;
Index: modules/help/help.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/help/help.test,v
retrieving revision 1.19
diff -u -p -r1.19 help.test
--- modules/help/help.test	1 Apr 2010 14:52:21 -0000	1.19
+++ modules/help/help.test	13 Jul 2010 15:59:44 -0000
@@ -2,6 +2,7 @@
 // $Id: help.test,v 1.19 2010/04/01 14:52:21 dries Exp $
 
 class HelpTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $big_user;
   protected $any_user;
 
Index: modules/image/image.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/image/image.test,v
retrieving revision 1.23
diff -u -p -r1.23 image.test
--- modules/image/image.test	30 Jun 2010 22:37:49 -0000	1.23
+++ modules/image/image.test	13 Jul 2010 15:59:46 -0000
@@ -108,6 +108,7 @@ class ImageFieldTestCase extends DrupalW
  * Tests the functions for generating paths and URLs for image styles.
  */
 class ImageStylesPathAndUrlUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $style_name;
   protected $image_info;
   protected $image_filepath;
@@ -324,6 +325,7 @@ class ImageEffectsUnitTest extends Image
  * Tests creation, deletion, and editing of image styles and effects.
  */
 class ImageAdminStylesUnitTest extends ImageFieldTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -631,6 +633,8 @@ class ImageAdminStylesUnitTest extends I
  * Test class to check that formatters and display settings are working.
  */
 class ImageFieldDisplayTestCase extends ImageFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Image field display tests',
@@ -805,6 +809,8 @@ class ImageFieldDisplayTestCase extends 
  * Test class to check for various validations.
  */
 class ImageFieldValidateTestCase extends ImageFieldTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Image field validation tests',
Index: modules/locale/locale.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/locale/locale.test,v
retrieving revision 1.73
diff -u -p -r1.73 locale.test
--- modules/locale/locale.test	26 Jun 2010 19:55:47 -0000	1.73
+++ modules/locale/locale.test	13 Jul 2010 15:59:51 -0000
@@ -990,6 +990,8 @@ class LocaleInstallTest extends DrupalWe
  * Locale uninstall with English UI functional test.
  */
 class LocaleUninstallFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Locale uninstall (EN)',
@@ -1117,6 +1119,8 @@ class LocaleUninstallFunctionalTest exte
  * to test with this new language.
  */
 class LocaleUninstallFrenchFunctionalTest extends LocaleUninstallFunctionalTest {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Locale uninstall (FR)',
@@ -1136,6 +1140,7 @@ class LocaleUninstallFrenchFunctionalTes
  * Functional tests for the language switching feature.
  */
 class LocaleLanguageSwitchingFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -1215,6 +1220,8 @@ class LocaleLanguageSwitchingFunctionalT
  * Functional tests for a user's ability to change their default language.
  */
 class LocaleUserLanguageFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User language settings',
@@ -1412,6 +1419,8 @@ class LocaleUserCreationTest extends Dru
  * Functional tests for configuring a different path alias per language.
  */
 class LocalePathFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Path language settings',
@@ -1494,6 +1503,8 @@ class LocalePathFunctionalTest extends D
  * Functional tests for multilingual support on nodes.
  */
 class LocaleContentFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Content language settings',
@@ -1817,6 +1828,8 @@ class LocaleUILanguageNegotiationTest ex
  * Functional test for multilingual fields.
  */
 class LocaleMultilingualFieldsFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Multilingual fields',
@@ -1925,6 +1938,7 @@ class LocaleMultilingualFieldsFunctional
  * Functional tests for localizing date formats.
  */
 class LocaleDateFormatsFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/menu/menu.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/menu/menu.test,v
retrieving revision 1.36
diff -u -p -r1.36 menu.test
--- modules/menu/menu.test	6 May 2010 05:59:31 -0000	1.36
+++ modules/menu/menu.test	13 Jul 2010 15:59:52 -0000
@@ -7,6 +7,7 @@
  */
 
 class MenuTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $big_user;
   protected $std_user;
   protected $menu;
@@ -542,6 +543,8 @@ class MenuTestCase extends DrupalWebTest
  * Test menu settings for nodes.
  */
 class MenuNodeTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Menu settings for nodes',
Index: modules/node/node.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/node/node.test,v
retrieving revision 1.89
diff -u -p -r1.89 node.test
--- modules/node/node.test	8 Jul 2010 03:41:27 -0000	1.89
+++ modules/node/node.test	13 Jul 2010 15:59:53 -0000
@@ -5,6 +5,7 @@
  * Test the node_load_multiple() function.
  */
 class NodeLoadMultipleUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -82,6 +83,7 @@ class NodeLoadMultipleUnitTest extends D
 }
 
 class NodeRevisionsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $nodes;
   protected $logs;
 
@@ -215,6 +217,7 @@ class NodeRevisionsTestCase extends Drup
 }
 
 class PageEditTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $web_user;
   protected $admin_user;
 
@@ -347,6 +350,8 @@ class PageEditTestCase extends DrupalWeb
 }
 
 class PagePreviewTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node preview',
@@ -418,6 +423,8 @@ class PagePreviewTestCase extends Drupal
 }
 
 class NodeCreationTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node creation',
@@ -504,6 +511,11 @@ class PageViewTestCase extends DrupalWeb
     );
   }
 
+  public function setUp() {
+    parent::setUp();
+    $this->drupalCreateDefaultContentTypes();
+  }
+
   /**
    * Creates a node and then an anonymous and unpermissioned user attempt to edit the node.
    */
@@ -535,6 +547,8 @@ class PageViewTestCase extends DrupalWeb
 }
 
 class SummaryLengthTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Summary length',
@@ -577,6 +591,8 @@ class SummaryLengthTestCase extends Drup
 }
 
 class NodeTitleXSSTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node title XSS filtering',
@@ -611,6 +627,8 @@ class NodeTitleXSSTestCase extends Drupa
 }
 
 class NodeBlockTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block availability',
@@ -644,6 +662,8 @@ class NodeBlockTestCase extends DrupalWe
  * Check that the post information displays when enabled for a content type.
  */
 class NodePostSettingsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node post information display',
@@ -713,6 +733,8 @@ class NodePostSettingsTestCase extends D
  * sitewide RSS feed at rss.xml.
  */
 class NodeRSSContentTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node RSS Content',
@@ -774,6 +796,8 @@ class NodeRSSContentTestCase extends Dru
  * hook_node_access_records is covered in another test class.
  */
 class NodeAccessUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node access',
@@ -916,6 +940,7 @@ class NodeAccessRecordsUnitTest extends 
  * Test case to check node save related functionality, including import-save
  */
 class NodeSaveTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -1029,6 +1054,8 @@ class NodeSaveTestCase extends DrupalWeb
  * Tests related to node types.
  */
 class NodeTypeTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node types',
@@ -1172,6 +1199,8 @@ class NodeAccessRebuildTestCase extends 
  * Test node administration page functionality.
  */
 class NodeAdminTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node administration',
@@ -1294,6 +1323,7 @@ class NodeAdminTestCase extends DrupalWe
  * Test node title.
  */
 class NodeTitleTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
 
   public static function getInfo() {
@@ -1369,6 +1399,8 @@ class NodeFeedTestCase extends DrupalWeb
  * Functional tests for the node module blocks.
  */
 class NodeBlockFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node blocks',
@@ -1502,6 +1534,8 @@ class NodeBlockFunctionalTest extends Dr
  * Test multistep node forms basic options.
  */
 class MultiStepNodeFormBasicOptionsTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Multistep node form basic options',
@@ -1696,6 +1730,8 @@ class NodeQueryAlter extends DrupalWebTe
  * Test node token replacement in strings.
  */
 class NodeTokenReplaceTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Node token replacement',
Index: modules/openid/openid.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/openid/openid.test,v
retrieving revision 1.28
diff -u -p -r1.28 openid.test
--- modules/openid/openid.test	7 Jul 2010 08:05:01 -0000	1.28
+++ modules/openid/openid.test	13 Jul 2010 15:59:54 -0000
@@ -26,6 +26,7 @@ abstract class OpenIDWebTestCase extends
  * Test discovery and login using OpenID
  */
 class OpenIDFunctionalTestCase extends OpenIDWebTestCase {
+  protected $profile = 'standard';
   protected $web_user;
 
   public static function getInfo() {
@@ -270,6 +271,8 @@ class OpenIDFunctionalTestCase extends O
  * Test account registration using Simple Registration and Attribute Exchange.
  */
 class OpenIDRegistrationTestCase extends OpenIDWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'OpenID account registration',
Index: modules/path/path.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/path/path.test,v
retrieving revision 1.35
diff -u -p -r1.35 path.test
--- modules/path/path.test	26 Mar 2010 12:37:30 -0000	1.35
+++ modules/path/path.test	13 Jul 2010 15:59:54 -0000
@@ -7,6 +7,8 @@
  */
 
 class PathTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Path alias functionality',
@@ -169,6 +171,8 @@ class PathTestCase extends DrupalWebTest
  * Test URL aliases for taxonomy terms.
  */
 class PathTaxonomyTermTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Taxonomy term URL aliases',
@@ -230,6 +234,8 @@ class PathTaxonomyTermTestCase extends D
 }
 
 class PathLanguageTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Path aliases with translated nodes',
@@ -313,6 +319,8 @@ class PathLanguageTestCase extends Drupa
  * Tests the user interface for creating path aliases, with languages.
  */
 class PathLanguageUITestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Path aliases with languages',
Index: modules/php/php.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/php/php.test,v
retrieving revision 1.24
diff -u -p -r1.24 php.test
--- modules/php/php.test	7 Mar 2010 23:14:20 -0000	1.24
+++ modules/php/php.test	13 Jul 2010 15:59:54 -0000
@@ -50,6 +50,8 @@ class PHPTestCase extends DrupalWebTestC
  * Tests to make sure the PHP filter actually evaluates PHP code when used.
  */
 class PHPFilterTestCase extends PHPTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'PHP filter functionality',
@@ -91,6 +93,8 @@ class PHPFilterTestCase extends PHPTestC
  * Tests to make sure access to the PHP filter is properly restricted.
  */
 class PHPAccessTestCase extends PHPTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'PHP filter access check',
Index: modules/poll/poll.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/poll/poll.test,v
retrieving revision 1.35
diff -u -p -r1.35 poll.test
--- modules/poll/poll.test	23 Jun 2010 19:15:07 -0000	1.35
+++ modules/poll/poll.test	13 Jul 2010 15:59:55 -0000
@@ -242,6 +242,8 @@ class PollVoteTestCase extends PollTestC
 }
 
 class PollBlockTestCase extends PollTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block availability',
@@ -640,4 +642,5 @@ class PollExpirationTestCase extends Pol
     $elements = $this->xpath('//input[@id="edit-active-0"]');
     $this->assertTrue(isset($elements[0]) && !empty($elements[0]['checked']), t('Poll has expired.'), t('Poll'));
   }
-}
\ No newline at end of file
+}
+
Index: modules/profile/profile.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/profile/profile.test,v
retrieving revision 1.26
diff -u -p -r1.26 profile.test
--- modules/profile/profile.test	29 May 2010 11:37:33 -0000	1.26
+++ modules/profile/profile.test	13 Jul 2010 15:59:56 -0000
@@ -161,6 +161,8 @@ class ProfileTestCase extends DrupalWebT
 }
 
 class ProfileTestFields extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Test single fields',
@@ -205,6 +207,8 @@ class ProfileTestFields extends ProfileT
 }
 
 class ProfileTestSelect extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Test select field',
@@ -238,6 +242,8 @@ class ProfileTestSelect extends ProfileT
 }
 
 class ProfileTestDate extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Test date field',
@@ -282,6 +288,8 @@ class ProfileTestDate extends ProfileTes
 }
 
 class ProfileTestWeights extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Test field weights',
@@ -312,6 +320,8 @@ class ProfileTestWeights extends Profile
  * Test profile field autocompletion and access.
  */
 class ProfileTestAutocomplete extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Autocompletion',
@@ -365,6 +375,8 @@ class ProfileTestAutocomplete extends Pr
 }
 
 class ProfileBlockTestCase extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block availability',
@@ -453,6 +465,8 @@ class ProfileBlockTestCase extends Profi
  * Test profile browsing.
  */
 class ProfileTestBrowsing extends ProfileTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Profile browsing',
Index: modules/rdf/rdf.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/rdf/rdf.test,v
retrieving revision 1.24
diff -u -p -r1.24 rdf.test
--- modules/rdf/rdf.test	1 Jun 2010 18:29:41 -0000	1.24
+++ modules/rdf/rdf.test	13 Jul 2010 15:59:57 -0000
@@ -7,6 +7,8 @@
  */
 
 class RdfMappingHookTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF mapping hook',
@@ -43,6 +45,8 @@ class RdfMappingHookTestCase extends Dru
  * Test RDFa markup generation.
  */
 class RdfRdfaMarkupTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDFa markup',
@@ -191,6 +195,8 @@ class RdfRdfaMarkupTestCase extends Drup
 }
 
 class RdfCrudTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF mapping CRUD functions',
@@ -259,6 +265,8 @@ class RdfCrudTestCase extends DrupalWebT
 }
 
 class RdfMappingDefinitionTestCase extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF mapping definition functionality',
@@ -392,6 +400,7 @@ class RdfMappingDefinitionTestCase exten
 }
 
 class RdfCommentAttributesTestCase extends CommentHelperCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -554,6 +563,8 @@ class RdfCommentAttributesTestCase exten
 }
 
 class RdfTrackerAttributesTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF tracker page mapping',
@@ -669,6 +680,8 @@ class RdfTrackerAttributesTestCase exten
  * Tests for RDF namespaces declaration with hook_rdf_namespaces().
  */
 class RdfGetRdfNamespacesTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF namespaces',
Index: modules/search/search.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/search/search.test,v
retrieving revision 1.64
diff -u -p -r1.64 search.test
--- modules/search/search.test	8 Jun 2010 06:34:36 -0000	1.64
+++ modules/search/search.test	13 Jul 2010 15:59:59 -0000
@@ -237,6 +237,8 @@ class SearchMatchTestCase extends Drupal
 }
 
 class SearchBikeShed extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   protected $searching_user;
 
   public static function getInfo() {
@@ -267,6 +269,8 @@ class SearchBikeShed extends DrupalWebTe
 }
 
 class SearchAdvancedSearchForm extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   protected $node;
 
   public static function getInfo() {
@@ -330,6 +334,8 @@ class SearchAdvancedSearchForm extends D
 }
 
 class SearchRankingTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Search engine ranking',
@@ -536,6 +542,8 @@ class SearchRankingTestCase extends Drup
 }
 
 class SearchBlockTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block availability',
@@ -597,6 +605,8 @@ class SearchBlockTestCase extends Drupal
  * Tests that searching for a phrase gets the correct page count.
  */
 class SearchExactTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Search engine phrase queries',
@@ -658,6 +668,7 @@ class SearchExactTestCase extends Drupal
  * Test integration searching comments.
  */
 class SearchCommentTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
 
   public static function getInfo() {
@@ -857,6 +868,7 @@ class SearchCommentTestCase extends Drup
  * - Nodes with comment status set to Hidden should never show comment counts
  */
 class SearchCommentCountToggleTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $searching_user;
   protected $searchable_nodes;
   
@@ -975,6 +987,8 @@ class SearchSimplifyTestCase extends Dru
  * Test config page.
  */
 class SearchConfigSettingsForm extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Config settings form',
Index: modules/shortcut/shortcut.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/shortcut/shortcut.test,v
retrieving revision 1.3
diff -u -p -r1.3 shortcut.test
--- modules/shortcut/shortcut.test	30 Jun 2010 15:12:59 -0000	1.3
+++ modules/shortcut/shortcut.test	13 Jul 2010 15:59:59 -0000
@@ -99,6 +99,7 @@ class ShortcutTestCase extends DrupalWeb
  * Defines shortcut links test cases.
  */
 class ShortcutLinksTestCase extends ShortcutTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -193,6 +194,7 @@ class ShortcutLinksTestCase extends Shor
  * Defines shortcut set test cases.
  */
 class ShortcutSetsTestCase extends ShortcutTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/simpletest/simpletest.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/simpletest.test,v
retrieving revision 1.43
diff -u -p -r1.43 simpletest.test
--- modules/simpletest/simpletest.test	28 Jun 2010 19:57:34 -0000	1.43
+++ modules/simpletest/simpletest.test	13 Jul 2010 16:00:07 -0000
@@ -2,6 +2,8 @@
 // $Id: simpletest.test,v 1.43 2010/06/28 19:57:34 dries Exp $
 
 class SimpleTestFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   /**
    * The results array that has been parsed by getTestResults().
    */
Index: modules/simpletest/tests/actions.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/actions.test,v
retrieving revision 1.16
diff -u -p -r1.16 actions.test
--- modules/simpletest/tests/actions.test	26 May 2010 11:26:49 -0000	1.16
+++ modules/simpletest/tests/actions.test	13 Jul 2010 16:00:07 -0000
@@ -68,6 +68,8 @@ class ActionsConfigurationTestCase exten
  * Test actions executing in a potential loop, and make sure they abort properly.
  */
 class ActionLoopTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Actions executing in a potentially infinite loop',
Index: modules/simpletest/tests/ajax.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/ajax.test,v
retrieving revision 1.11
diff -u -p -r1.11 ajax.test
--- modules/simpletest/tests/ajax.test	30 Apr 2010 08:07:55 -0000	1.11
+++ modules/simpletest/tests/ajax.test	13 Jul 2010 16:00:08 -0000
@@ -217,6 +217,8 @@ class AJAXFormValuesTestCase extends AJA
  * Tests that AJAX-enabled forms work when multiple instances of the same form are on a page.
  */
 class AJAXMultiFormTestCase extends AJAXTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'AJAX multi form',
@@ -299,6 +301,8 @@ class AJAXMultiFormTestCase extends AJAX
  * Miscellaneous AJAX tests using ajax_test module.
  */
 class AJAXElementValidation extends AJAXTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Miscellaneous AJAX tests',
Index: modules/simpletest/tests/bootstrap.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/bootstrap.test,v
retrieving revision 1.31
diff -u -p -r1.31 bootstrap.test
--- modules/simpletest/tests/bootstrap.test	14 Jun 2010 13:24:32 -0000	1.31
+++ modules/simpletest/tests/bootstrap.test	13 Jul 2010 16:00:09 -0000
@@ -100,6 +100,7 @@ class BootstrapIPAddressTestCase extends
 }
 
 class BootstrapPageCacheTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -224,6 +225,7 @@ class BootstrapPageCacheTestCase extends
 }
 
 class BootstrapVariableTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   function setUp() {
     parent::setUp('system_test');
Index: modules/simpletest/tests/common.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/common.test,v
retrieving revision 1.116
diff -u -p -r1.116 common.test
--- modules/simpletest/tests/common.test	7 Jul 2010 17:00:43 -0000	1.116
+++ modules/simpletest/tests/common.test	13 Jul 2010 16:00:09 -0000
@@ -546,6 +546,8 @@ class DrupalTagsHandlingTestCase extends
  * Test the Drupal CSS system.
  */
 class CascadingStylesheetsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Cascading stylesheets',
@@ -854,6 +856,8 @@ class CascadingStylesheetsUnitTest exten
  * Test drupal_http_request().
  */
 class DrupalHTTPRequestTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Drupal HTTP request',
@@ -1005,6 +1009,8 @@ class DrupalSetContentTestCase extends D
  * Testing drupal_goto and hook_drupal_goto_alter().
  */
 class DrupalGotoTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Drupal goto',
@@ -1074,6 +1080,8 @@ class DrupalGotoTest extends DrupalWebTe
  * Tests for the JavaScript system.
  */
 class JavaScriptTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   /**
    * Store configured value for JavaScript preprocessing.
    */
@@ -1774,6 +1782,7 @@ class ParseInfoFilesTestCase extends Dru
  * Tests for the format_date() function.
  */
 class FormatDateUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   /**
    * Arbitrary langcode for a custom language.
@@ -1961,6 +1970,8 @@ class DrupalJSONTest extends DrupalUnitT
  * Tests for RDF namespaces XML serialization.
  */
 class DrupalGetRdfNamespacesTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'RDF namespaces XML serialization tests',
Index: modules/simpletest/tests/file.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/file.test,v
retrieving revision 1.58
diff -u -p -r1.58 file.test
--- modules/simpletest/tests/file.test	30 Jun 2010 22:37:49 -0000	1.58
+++ modules/simpletest/tests/file.test	13 Jul 2010 16:00:11 -0000
@@ -342,6 +342,8 @@ class FileSpaceUsedTest extends FileTest
  *  This will run tests against the file validation functions (file_validate_*).
  */
 class FileValidatorTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'File validator tests',
Index: modules/simpletest/tests/form.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/form.test,v
retrieving revision 1.54
diff -u -p -r1.54 form.test
--- modules/simpletest/tests/form.test	10 Jul 2010 00:03:37 -0000	1.54
+++ modules/simpletest/tests/form.test	13 Jul 2010 16:00:12 -0000
@@ -243,6 +243,8 @@ class FormsTestCase extends DrupalWebTes
  * Test form alter hooks.
  */
 class FormAlterTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Form alter hooks',
@@ -277,6 +279,8 @@ class FormAlterTestCase extends DrupalWe
  * Test form validation handlers.
  */
 class FormValidationTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Form validation handlers',
@@ -353,6 +357,7 @@ class FormValidationTestCase extends Dru
  * Test form element labels, required markers and associated output.
  */
 class FormsElementsLabelsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -426,6 +431,7 @@ class FormsElementsLabelsTestCase extend
  * Test the tableselect form element for expected behavior.
  */
 class FormsElementsTableSelectFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -783,6 +789,8 @@ class FormsFormStorageTestCase extends D
  * Test wrapper form callbacks.
  */
 class FormsFormWrapperTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Form wrapper callback',
@@ -809,6 +817,8 @@ class FormsFormWrapperTestCase extends D
  * Test $form_state clearance.
  */
 class FormStateValuesCleanTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Form state values clearance',
@@ -859,6 +869,8 @@ class FormStateValuesCleanTestCase exten
  * @todo Add tests for other aspects of form rebuilding.
  */
 class FormsRebuildTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Form rebuilding',
Index: modules/simpletest/tests/menu.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/menu.test,v
retrieving revision 1.31
diff -u -p -r1.31 menu.test
--- modules/simpletest/tests/menu.test	8 Jul 2010 03:41:27 -0000	1.31
+++ modules/simpletest/tests/menu.test	13 Jul 2010 16:00:13 -0000
@@ -7,6 +7,8 @@
  */
 
 class MenuRouterTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Menu router',
Index: modules/simpletest/tests/module.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/module.test,v
retrieving revision 1.21
diff -u -p -r1.21 module.test
--- modules/simpletest/tests/module.test	22 Apr 2010 18:56:31 -0000	1.21
+++ modules/simpletest/tests/module.test	13 Jul 2010 16:00:13 -0000
@@ -10,6 +10,8 @@
  * Unit tests for the module API.
  */
 class ModuleUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Module API',
Index: modules/simpletest/tests/path.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/path.test,v
retrieving revision 1.5
diff -u -p -r1.5 path.test
--- modules/simpletest/tests/path.test	6 Apr 2010 19:49:03 -0000	1.5
+++ modules/simpletest/tests/path.test	13 Jul 2010 16:00:14 -0000
@@ -131,6 +131,8 @@ class DrupalMatchPathTestCase extends Dr
  * Tests hook_url_alter functions.
  */
 class UrlAlterFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => t('URL altering'),
Index: modules/simpletest/tests/session.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/session.test,v
retrieving revision 1.29
diff -u -p -r1.29 session.test
--- modules/simpletest/tests/session.test	14 Jun 2010 12:31:46 -0000	1.29
+++ modules/simpletest/tests/session.test	13 Jul 2010 16:00:14 -0000
@@ -7,6 +7,8 @@
  */
 
 class SessionTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Session tests',
@@ -227,6 +229,7 @@ class SessionTestCase extends DrupalWebT
  * Ensure that when running under https two session cookies are generated.
  */
 class SessionHttpsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/simpletest/tests/theme.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/tests/theme.test,v
retrieving revision 1.16
diff -u -p -r1.16 theme.test
--- modules/simpletest/tests/theme.test	29 Apr 2010 05:22:06 -0000	1.16
+++ modules/simpletest/tests/theme.test	13 Jul 2010 16:00:14 -0000
@@ -10,6 +10,8 @@
  * Unit tests for the Theme API.
  */
 class ThemeUnitTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Theme API',
Index: modules/statistics/statistics.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/statistics/statistics.test,v
retrieving revision 1.20
diff -u -p -r1.20 statistics.test
--- modules/statistics/statistics.test	8 Jul 2010 03:41:27 -0000	1.20
+++ modules/statistics/statistics.test	13 Jul 2010 16:00:16 -0000
@@ -40,6 +40,8 @@ class StatisticsTestCase extends DrupalW
  * to test requests from an anonymous user.
  */
 class StatisticsLoggingTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Statistics logging tests',
@@ -100,6 +102,8 @@ class StatisticsLoggingTestCase extends 
  * Tests that report pages render properly, and that access logging works.
  */
 class StatisticsReportsTestCase extends StatisticsTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Statistics reports tests',
@@ -190,6 +194,8 @@ class StatisticsReportsTestCase extends 
  * Tests that the visitor blocking functionality works.
  */
 class StatisticsBlockVisitorsTestCase extends StatisticsTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Top visitor blocking',
@@ -240,6 +246,7 @@ class StatisticsBlockVisitorsTestCase ex
  * Test statistics administration screen.
  */
 class StatisticsAdminTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $privileged_user;
   protected $test_node;
 
@@ -380,6 +387,8 @@ class StatisticsAdminTestCase extends Dr
  * Test statistics token replacement in strings.
  */
 class StatisticsTokenReplaceTestCase extends StatisticsTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Statistics token replacement',
Index: modules/system/system.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/system/system.test,v
retrieving revision 1.132
diff -u -p -r1.132 system.test
--- modules/system/system.test	11 Jul 2010 01:01:11 -0000	1.132
+++ modules/system/system.test	13 Jul 2010 16:00:23 -0000
@@ -92,6 +92,8 @@ class ModuleTestCase extends DrupalWebTe
  * Test module enabling/disabling functionality.
  */
 class EnableDisableTestCase extends ModuleTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Enable/disable modules',
@@ -202,6 +204,8 @@ class HookRequirementsTestCase extends M
  * Test module dependency functionality.
  */
 class ModuleDependencyTestCase extends ModuleTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Module dependencies',
@@ -462,6 +466,8 @@ class IPAddressBlockingTestCase extends 
 }
 
 class CronRunTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   /**
    * Implement getInfo().
    */
@@ -608,6 +614,8 @@ class AdminMetaTagTestCase extends Drupa
 class AccessDeniedTestCase extends DrupalWebTestCase {
   protected $admin_user;
 
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => '403 functionality',
@@ -681,6 +689,8 @@ class AccessDeniedTestCase extends Drupa
 class PageNotFoundTestCase extends DrupalWebTestCase {
   protected $admin_user;
 
+  protected $profile = 'standard';
+
   /**
    * Implement getInfo().
    */
@@ -826,6 +836,8 @@ class SiteMaintenanceTestCase extends Dr
  * Tests generic date and time handling capabilities of Drupal.
  */
 class DateTimeFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Date and time',
@@ -947,6 +959,7 @@ class DateTimeFunctionalTest extends Dru
 }
 
 class PageTitleFiltering extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $content_user;
   protected $saved_title;
 
@@ -1107,6 +1120,8 @@ class FrontPageTestCase extends DrupalWe
 }
 
 class SystemBlockTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Block functionality',
@@ -1161,6 +1176,7 @@ class SystemBlockTestCase extends Drupal
  * Test main content rendering fallback provided by system module.
  */
 class SystemMainContentFallback extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
   protected $web_user;
 
@@ -1245,6 +1261,8 @@ class SystemMainContentFallback extends 
  * Tests for the theme interface functionality.
  */
 class SystemThemeFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Theme interface functionality',
@@ -1437,6 +1455,8 @@ class QueueTestCase extends DrupalWebTes
  * Test token replacement in strings.
  */
 class TokenReplaceTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Token replacement',
@@ -1636,6 +1656,7 @@ array_space[a b] = Value';
  * Tests for the update system functionality.
  */
 class UpdateScriptFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
   private $update_url;
   private $update_user;
 
Index: modules/taxonomy/taxonomy.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/taxonomy/taxonomy.test,v
retrieving revision 1.81
diff -u -p -r1.81 taxonomy.test
--- modules/taxonomy/taxonomy.test	1 Jul 2010 00:42:34 -0000	1.81
+++ modules/taxonomy/taxonomy.test	13 Jul 2010 16:00:23 -0000
@@ -44,6 +44,7 @@ class TaxonomyWebTestCase extends Drupal
 * Tests for the taxonomy vocabulary interface.
 */
 class TaxonomyVocabularyFunctionalTest extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -180,6 +181,7 @@ class TaxonomyVocabularyFunctionalTest e
  * Tests for taxonomy vocabulary functions.
  */
 class TaxonomyVocabularyUnitTest extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -343,6 +345,7 @@ class TaxonomyTermUnitTest extends Taxon
  * Tests for taxonomy term functions.
  */
 class TaxonomyTermTestCase extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -658,6 +661,7 @@ class TaxonomyTermTestCase extends Taxon
  * Test the taxonomy_term_load_multiple() function.
  */
 class TaxonomyLoadMultipleUnitTest extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
@@ -776,6 +780,7 @@ class TaxonomyHooksTestCase extends Taxo
  * Tests for taxonomy term field and formatter.
  */
 class TaxonomyTermFieldTestCase extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
   protected $instance;
   protected $vocabulary;
 
@@ -922,6 +927,8 @@ class TaxonomyTermFieldTestCase extends 
  * Test taxonomy token replacement in strings.
  */
 class TaxonomyTokenReplaceTestCase extends TaxonomyWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Taxonomy token replacement',
Index: modules/tracker/tracker.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/tracker/tracker.test,v
retrieving revision 1.18
diff -u -p -r1.18 tracker.test
--- modules/tracker/tracker.test	9 Jan 2010 21:54:01 -0000	1.18
+++ modules/tracker/tracker.test	13 Jul 2010 16:00:23 -0000
@@ -2,6 +2,7 @@
 // $Id: tracker.test,v 1.18 2010/01/09 21:54:01 webchick Exp $
 
 class TrackerTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $user;
   protected $other_user;
   protected $new_node;
Index: modules/translation/translation.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/translation/translation.test,v
retrieving revision 1.26
diff -u -p -r1.26 translation.test
--- modules/translation/translation.test	6 Jun 2010 00:24:16 -0000	1.26
+++ modules/translation/translation.test	13 Jul 2010 16:00:23 -0000
@@ -2,6 +2,7 @@
 // $Id: translation.test,v 1.26 2010/06/06 00:24:16 webchick Exp $
 
 class TranslationTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $book;
 
   public static function getInfo() {
Index: modules/trigger/trigger.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/trigger/trigger.test,v
retrieving revision 1.33
diff -u -p -r1.33 trigger.test
--- modules/trigger/trigger.test	29 Jun 2010 18:24:10 -0000	1.33
+++ modules/trigger/trigger.test	13 Jul 2010 16:00:24 -0000
@@ -34,6 +34,7 @@ class TriggerWebTestCase extends DrupalW
  * Provides tests for node triggers.
  */
 class TriggerContentTestCase extends TriggerWebTestCase {
+  protected $profile = 'standard';
   var $_cleanup_roles = array();
   var $_cleanup_users = array();
 
@@ -250,6 +251,7 @@ class TriggerCronTestCase extends Trigge
  * Provides a base class with trigger assignments and test comparisons.
  */
 class TriggerActionTestCase extends TriggerWebTestCase {
+  protected $profile = 'standard';
 
   function setUp() {
     parent::setUp('trigger');
@@ -434,7 +436,6 @@ class TriggerUserTokenTestCase extends T
     );
   }
 
-
   /**
    * Tests a variety of token replacements in actions.
    */
@@ -473,7 +474,6 @@ class TriggerUserTokenTestCase extends T
     $this->assertSystemMessageAndEmailTokenReplacement('user_delete', $user_to_delete);
   }
 
-
 }
 
 /**
@@ -483,6 +483,8 @@ class TriggerUserTokenTestCase extends T
  * and checks the token replacement.
  */
 class TriggerUserActionTestCase extends TriggerActionTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Test user actions',
@@ -539,6 +541,7 @@ class TriggerUserActionTestCase extends 
  * Tests other triggers.
  */
 class TriggerOtherTestCase extends TriggerWebTestCase {
+  protected $profile = 'standard';
   var $_cleanup_roles = array();
   var $_cleanup_users = array();
 
@@ -682,6 +685,7 @@ class TriggerOtherTestCase extends Trigg
  * Tests that orphaned actions are properly handled.
  */
 class TriggerOrphanedActionsTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/update/update.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/update/update.test,v
retrieving revision 1.13
diff -u -p -r1.13 update.test
--- modules/update/update.test	4 Jan 2010 21:31:52 -0000	1.13
+++ modules/update/update.test	13 Jul 2010 16:00:24 -0000
@@ -52,6 +52,7 @@ class UpdateTestHelper extends DrupalWeb
 }
 
 class UpdateCoreTestCase extends UpdateTestHelper {
+  protected $profile = 'standard';
 
   public static function getInfo() {
     return array(
Index: modules/user/user.test
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.test,v
retrieving revision 1.95
diff -u -p -r1.95 user.test
--- modules/user/user.test	10 Jun 2010 06:57:20 -0000	1.95
+++ modules/user/user.test	13 Jul 2010 16:00:25 -0000
@@ -319,6 +319,8 @@ class UserLoginTestCase extends DrupalWe
  * Test cancelling a user.
  */
 class UserCancelTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'Cancel account',
@@ -714,6 +716,7 @@ class UserCancelTestCase extends DrupalW
 }
 
 class UserPictureTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $user;
   protected $_directory_test;
 
@@ -1029,6 +1032,8 @@ class UserPermissionsTestCase extends Dr
 }
 
 class UserAdminTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User administration',
@@ -1085,6 +1090,8 @@ class UserAdminTestCase extends DrupalWe
  * Tests for user-configurable time zones.
  */
 class UserTimeZoneFunctionalTest extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User time zones',
@@ -1145,6 +1152,8 @@ class UserTimeZoneFunctionalTest extends
  * Test user autocompletion.
  */
 class UserAutocompleteTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User autocompletion',
@@ -1185,6 +1194,8 @@ class UserAutocompleteTestCase extends D
  * Test user blocks.
  */
 class UserBlocksUnitTests extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User blocks',
@@ -1438,6 +1449,8 @@ class UserEditTestCase extends DrupalWeb
  * Test case for user signatures.
  */
 class UserSignatureTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User signatures',
@@ -1686,6 +1699,8 @@ class UserTokenReplaceTestCase extends D
  * Test user search.
  */
 class UserUserSearchTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
+
   public static function getInfo() {
     return array(
       'name' => 'User search',
@@ -1718,6 +1733,7 @@ class UserUserSearchTestCase extends Dru
  * Test role assignment.
  */
 class UserRolesAssignmentTestCase extends DrupalWebTestCase {
+  protected $profile = 'standard';
   protected $admin_user;
 
   public static function getInfo() {
Index: profiles/standard/standard.install
===================================================================
RCS file: /cvs/drupal/drupal/profiles/standard/standard.install,v
retrieving revision 1.18
diff -u -p -r1.18 standard.install
--- profiles/standard/standard.install	8 Jul 2010 03:41:27 -0000	1.18
+++ profiles/standard/standard.install	13 Jul 2010 16:00:25 -0000
@@ -202,35 +202,7 @@ function standard_install() {
   }
   $query->execute();
 
-  // Insert default pre-defined node types into the database. For a complete
-  // list of available node type attributes, refer to the node type API
-  // documentation at: http://api.drupal.org/api/HEAD/function/hook_node_info.
-  $types = array(
-    array(
-      'type' => 'page',
-      'name' => st('Basic page'),
-      'base' => 'node_content',
-      'description' => st("Use <em>basic pages</em> for your static content, such as an 'About us' page."),
-      'custom' => 1,
-      'modified' => 1,
-      'locked' => 0,
-    ),
-    array(
-      'type' => 'article',
-      'name' => st('Article'),
-      'base' => 'node_content',
-      'description' => st('Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.'),
-      'custom' => 1,
-      'modified' => 1,
-      'locked' => 0,
-    ),
-  );
-
-  foreach ($types as $type) {
-    $type = node_type_set_defaults($type);
-    node_type_save($type);
-    node_add_body_field($type);
-  }
+  standard_create_default_content_types();
 
   // Insert default pre-defined RDF mapping into the database.
   $rdf_mappings = array(
@@ -427,3 +399,39 @@ function standard_install() {
   variable_set('admin_theme', 'seven');
   variable_set('node_admin_theme', '1');
 }
+
+/**
+ * Create some default content types.
+ *
+ * For a complete list of available node type attributes, refer to the node 
+ * type API documentation at:
+ * http://api.drupal.org/api/HEAD/function/hook_node_info.
+ */
+function standard_create_default_content_types() {
+  $types = array(
+    array(
+      'type' => 'page',
+      'name' => st('Basic page'),
+      'base' => 'node_content',
+      'description' => st("Use <em>basic pages</em> for your static content, such as an 'About us' page."),
+      'custom' => 1,
+      'modified' => 1,
+      'locked' => 0,
+    ),
+    array(
+      'type' => 'article',
+      'name' => st('Article'),
+      'base' => 'node_content',
+      'description' => st('Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.'),
+      'custom' => 1,
+      'modified' => 1,
+      'locked' => 0,
+    ),
+  );
+  foreach ($types as $type) {
+    $type = node_type_set_defaults($type);
+    node_type_save($type);
+    node_add_body_field($type);
+  }
+}
+

Index: modules/simpletest/drupal_web_test_case.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/simpletest/drupal_web_test_case.php,v
retrieving revision 1.224
diff -u -p -r1.224 drupal_web_test_case.php
--- modules/simpletest/drupal_web_test_case.php	8 Jul 2010 12:22:59 -0000	1.224
+++ modules/simpletest/drupal_web_test_case.php	13 Jul 2010 16:00:05 -0000
@@ -1125,6 +1125,11 @@ class DrupalWebTestCase extends DrupalTe
   protected function setUp() {
     global $user, $language, $conf;
 
+    // Allow tests to use a profile other than the testing one.
+    if (!isset($this->profile)) {
+      $this->profile = 'testing';
+    }
+
     // Generate a temporary prefixed database to ensure that tests have a clean starting point.
     $this->databasePrefix = 'simpletest' . mt_rand(1000, 1000000);
     db_update('simpletest_test_id')
@@ -1193,11 +1198,11 @@ class DrupalWebTestCase extends DrupalTe
     variable_set('file_private_path', $private_files_directory);
     variable_set('file_temporary_path', $temp_files_directory);
 
-    // Include the default profile.
-    variable_set('install_profile', 'standard');
-    $profile_details = install_profile_info('standard', 'en');
+    // Include the testing profile.
+    variable_set('install_profile', $this->profile);
+    $profile_details = install_profile_info($this->profile, 'en');
 
     // Install the modules specified by the default profile.
     module_enable($profile_details['dependencies'], FALSE);
 
     // Install modules needed for this test. This could have been passed in as
@@ -1213,7 +1218,12 @@ class DrupalWebTestCase extends DrupalTe
     }
 
     // Run default profile tasks.
-    module_enable(array('standard'), FALSE);
+    $install_profile_module_exists = db_query("SELECT 1 FROM {system} WHERE type = 'module' AND name = :name", array(
+      ':name' => $this->profile))
+      ->fetchField();
+    if ($install_profile_module_exists) {
+      module_enable(array($this->profile), FALSE);
+    }
 
     // Rebuild caches.
     drupal_static_reset();
@@ -3065,6 +3075,17 @@ class DrupalWebTestCase extends DrupalTe
     }
   }
 
+  /**
+   * Create default content types.
+   *
+   * @see standard_create_default_content_types()
+   */
+  protected function drupalCreateDefaultContentTypes() {
+    module_load_install('standard');
+    standard_create_default_content_types();
+    menu_rebuild();
+  }
+
 }
 
 /**
@@ -1193,11 +1198,11 @@ class DrupalWebTestCase extends DrupalTe
 
-    // Install the modules specified by the default profile.
+    // Install the modules specified by the testing profile.
     module_enable($profile_details['dependencies'], FALSE);
 